Author: garga (ports committer)
Date: Fri Jun  3 18:37:56 2016
New Revision: 301280
URL: https://svnweb.freebsd.org/changeset/base/301280

Log:
  One of the already implemented options in release/Makefile is NOSRC. When
  it's defined, installation image is shipped without source distribution
  (src.txz)
  
  Add the hability of defining NOSRC in release.conf and pass it to
  'make release' argument
  
  Approved by:  gjb
  Sponsored by: Rubicon Communications (Netgate)
  Differential Revision:        https://reviews.freebsd.org/D6710

Modified:
  head/release/release.conf.sample
  head/release/release.sh

Modified: head/release/release.conf.sample
==============================================================================
--- head/release/release.conf.sample    Fri Jun  3 18:23:45 2016        
(r301279)
+++ head/release/release.conf.sample    Fri Jun  3 18:37:56 2016        
(r301280)
@@ -51,6 +51,7 @@ PORTBRANCH="ports/head@rHEAD"
 ## Set miscellaneous 'make release' settings.
 #NODOC=
 #NOPORTS=
+#NOSRC=
 #WITH_DVD=
 #WITH_COMPRESSED_IMAGES=
 

Modified: head/release/release.sh
==============================================================================
--- head/release/release.sh     Fri Jun  3 18:23:45 2016        (r301279)
+++ head/release/release.sh     Fri Jun  3 18:37:56 2016        (r301280)
@@ -102,6 +102,9 @@ env_setup() {
        NODOC=
        NOPORTS=
 
+       # Set to non-empty value to disable distributing source tree.
+       NOSRC=
+
        # Set to non-empty value to build dvd1.iso as part of the release.
        WITH_DVD=
        WITH_COMPRESSED_IMAGES=
@@ -160,15 +163,18 @@ env_check() {
                NODOC=yes
        fi
 
        # If NOPORTS and/or NODOC are unset, they must not pass to make as
        # variables.  The release makefile verifies definedness of the
        # NOPORTS/NODOC variables instead of their values.
-       DOCPORTS=
+       SRCDOCPORTS=
        if [ -n "${NOPORTS}" ]; then
-               DOCPORTS="NOPORTS=yes "
+               SRCDOCPORTS="NOPORTS=yes"
        fi
        if [ -n "${NODOC}" ]; then
-               DOCPORTS="${DOCPORTS}NODOC=yes"
+               SRCDOCPORTS="${SRCDOCPORTS}${SRCDOCPORTS:+ }NODOC=yes"
+       fi
+       if [ -n "${NOSRC}" ]; then
+               SRCDOCPORTS="${SRCDOCPORTS}${SRCDOCPORTS:+ }NOSRC=yes"
        fi
 
        # The aggregated build-time flags based upon variables defined within
@@ -206,7 +212,7 @@ env_check() {
        RELEASE_KMAKEFLAGS="${MAKE_FLAGS} ${KERNEL_FLAGS} \
                KERNCONF=\"${KERNEL}\" ${ARCH_FLAGS} ${CONF_FILES}"
        RELEASE_RMAKEFLAGS="${ARCH_FLAGS} \
-               KERNCONF=\"${KERNEL}\" ${CONF_FILES} ${DOCPORTS} \
+               KERNCONF=\"${KERNEL}\" ${CONF_FILES} ${SRCDOCPORTS} \
                WITH_DVD=${WITH_DVD} WITH_VMIMAGES=${WITH_VMIMAGES} \
                WITH_CLOUDWARE=${WITH_CLOUDWARE} XZ_THREADS=${XZ_THREADS}"
 
@@ -160,15 +163,18 @@ env_check() {
        fi
 
-       # If NOPORTS and/or NODOC are unset, they must not pass to make as
-       # variables.  The release makefile verifies definedness of the
+       # If NOSRC, NOPORTS and/or NODOC are unset, they must not pass to make
+       # as variables.  The release makefile verifies definedness of the
        # NOPORTS/NODOC variables instead of their values.
_______________________________________________
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"

Reply via email to